
import { useRef, useState, useEffect } from 'react';
import { connect } from '@umijs/max';
import type { ActionType, ProFormInstance } from '@ant-design/pro-components';
import {
    ProFormText,
    ProFormSegmented,
    ProFormSelect,
    ProForm,
    FormControlRender,
    ProFormDependency,
    ProFormSwitch,
    ProFormCascader,
    ProFormDatePicker
} from '@ant-design/pro-components';
import { ConfigProvider, Flex, Space, Modal, message, Image, Row, Col, Switch, Form, Typography, Divider } from 'antd';
import { addArticle, updateArticle, listSection, GetArticleDetail } from '@/apis/api';
import { Imageprefix } from '@/constants';
import UploadModel from '@/components/Common/upload';
import DragUpload from '@/components/Common/dragupload';
import RichComponent from '@/components/Common/rich';
import he from 'he';

import { isArrayOfType } from '@/utils/dataHelper';


const selectfieldNames = { label: 'name', value: 'id' };
const cascaderfieldNames = { label: 'name', value: 'id', children: 'childs' };

const PagesMainInformationArticleCreate: React.FC = ({ dispatch, dictModel, openModel, id }: any) => {
    const formRef = useRef<ProFormInstance>();
    const [openPreview, setOpenPreview] = useState(false);
    const [detail, setDetail] = useState<InformationType.article | null>(null)

    useEffect(() => {
        setOpenPreview(openModel.openModal)
    }, [openModel.openModal])


    useEffect(() => {
        dispatch({ type: 'dictModel/getList', payload: { code: 2004, type: 'setPositionList' } })
        dispatch({ type: 'dictModel/getList', payload: { code: 2009, type: 'setAreaList' } })
        dispatch({ type: 'dictModel/getList', payload: { code: 2005, type: 'setPayList' } })
        dispatch({ type: 'dictModel/getList', payload: { code: 2016, type: 'setAccommodationRequirementList' } })
        dispatch({ type: 'dictModel/getList', payload: { code: 2017, type: 'setHolidayRestList' } })
        dispatch({ type: 'dictModel/getList', payload: { code: 2018, type: 'setLicenseList' } })
        dispatch({ type: 'dictModel/getList', payload: { code: 2021, type: 'setWorkExperienceList' } })
        dispatch({ type: 'dictModel/getList', payload: { code: 2006, type: 'setEducationList' } })
        dispatch({ type: 'dictModel/getList', payload: { code: 2014, type: 'setTitleList' } })
        dispatch({ type: 'dictModel/getList', payload: { code: 2015, type: 'setSkillCertificationeList' } })
        dispatch({ type: 'dictModel/getList', payload: { code: 2007, type: 'setOtherLanguageList' } })
        dispatch({ type: 'dictModel/getList', payload: { code: 2008, type: 'setDegreeList' } })
        dispatch({ type: 'dictModel/getList', payload: { code: 2027, type: 'setIndustryPostList' } })
        dispatch({ type: 'dictModel/getList', payload: { code: 2010, type: 'setPoliticalList' } })
    }, [])


    return (
        <>
            <ConfigProvider
                theme={{
                    token: {
                        colorPrimary: '#4FBE70',
                    }
                }}
            >
                <Modal
                    open={openPreview}
                    title={id ? '编辑公共户口' : '添加公共户口'}
                    centered
                    maskClosable={false}
                    footer={null}
                    destroyOnClose
                    width={1000}
                    onCancel={() => {
                        dispatch({ type: 'openModel/getOpenModal', payload: false })
                    }}
                >
                    <ProForm<InformationType.article>
                        formRef={formRef}
                        request={async () => {
                            if (id) {
                                let res = await GetArticleDetail({ id: id })
                                setUploadedFilephotoName(res.data.cover_img)
                                res.data.section_arr = [res.data.section_name]

                                setDetail(res.data)
                                return res.data;
                            } else {
                                setDetail(null)
                                setUploadedFilephotoName('')
                                return {
                                    title: '',
                                    cover_img: '',
                                    doc_url: '',
                                    section_id: null,
                                    content: '',
                                    stick_top: 0,
                                    hot: 0,
                                    author: ''
                                }
                            }
                        }}
                        submitter={{
                            searchConfig: {
                                resetText: '取消',
                                submitText: '保存',
                            },
                            render: (_, dom) => { return <Flex justify='flex-end'> <Space>{dom}</Space></Flex> },
                            onReset: () => {
                                setDetail(null)
                                dispatch({ type: 'openModel/getOpenModal', payload: false })
                            }
                        }}
                        onFinish={async (values) => {
                            values.cover_img = uploadedFilephotoName ? uploadedFilephotoName : '';

                            if (id) {
                                values.id = id;
                                // 判断是字符串数组还是数字数组
                                if (isArrayOfType(values.section_arr, 'string')) {
                                    // 是字符串
                                    values.section_id = detail?.section_id
                                } else {
                                    values.section_id = values.section_arr.length > 0 ? values.section_arr[values.section_arr.length - 1] : 0;
                                    delete values.section_arr;
                                }
                                let res = await updateArticle(values)
                                message.success('提交成功')
                                dispatch({ type: 'openModel/getOpenModal', payload: false })
                            } else {
                                values.section_id = values.section_arr.length > 0 ? values.section_arr[values.section_arr.length - 1] : 0;
                                delete values.section_arr;
                                let res = await addArticle(values)
                                message.success('提交成功')
                                dispatch({ type: 'openModel/getOpenModal', payload: false })
                            }
                        }}
                    >
                        <Row gutter={[16, 16]}>
                            <Col span={24}>
                                <Divider orientation="left" plain >户口本信息</Divider>
                            </Col>
                            <Col span={8}>
                                <ProFormText

                                    name="author"
                                    label="户口本存放位编号"
                                    placeholder="436346"
                                    rules={[{ required: true, message: '请输入户口本存放位编号' }]}
                                />
                            </Col>
                            <Col span={8}>
                                <ProFormText

                                    name="author"
                                    label="单位名称"
                                    placeholder="菊城人才市场"
                                    rules={[{ required: true, message: '请输入单位名称' }]}
                                />
                            </Col>
                            <Col span={8}>
                                <ProFormText
                                    name="author"
                                    label="入户人数"
                                    placeholder="10"
                                />
                            </Col>
                            <Col span={24}>
                                <Divider orientation="left" plain >入户人员信息</Divider>
                            </Col>
                            <Col span={8}>
                                <ProFormSegmented
                                    name="gender"
                                    label="是否随家人迁入"
                                    request={async () => [
                                        { label: '是', value: 1 },
                                        { label: '否', value: 2 }
                                    ]}
                                />
                            </Col>
                            <Col span={16}>
                                <ProFormSelect
                                width={'md'}
                                    name="education"
                                    label="选择随迁人员"
                                    fieldProps={{
                                        fieldNames: selectfieldNames
                                    }}
                                    options={dictModel.educationList}
                                />
                            </Col>
                            <Col span={8}>
                                <ProFormText
                                    name="author"
                                    label="姓名"
                                    placeholder="10"
                                />
                            </Col>
                            <Col span={8}>
                                <ProFormText
                                    label="身份证"
                                    name="id_number"
                                    placeholder="请输入身份证"
                                    validateTrigger='onBlur'
                                    rules={[{
                                        required: false,
                                    }, () => ({
                                        validator: (rule, value) => {
                                            let info = verifyIdCard(value);


                                            if (typeof (info) == 'boolean') {
                                                return Promise.resolve();
                                            }
                                            return Promise.reject(new Error(info));
                                        }
                                    })]}
                                />
                            </Col>
                            <Col span={8}>
                                <ProFormSegmented
                                    name="gender"
                                    label="性别"
                                    request={async () => [
                                        { label: '男', value: '男' },
                                        { label: '女', value: '女' }
                                    ]}
                                />
                            </Col>
                            <Col span={8}>
                                <ProFormSelect
                                    name="education"
                                    label="学历"
                                    fieldProps={{
                                        fieldNames: selectfieldNames
                                    }}
                                    options={dictModel.educationList}
                                />
                            </Col>
                            <Col span={8}>
                                <ProFormSelect
                                    name="political_status"
                                    label="政治面貌"
                                    fieldProps={{
                                        fieldNames: selectfieldNames
                                    }}
                                    options={dictModel.politicalList}
                                />
                            </Col>
                            <Col span={8}>
                                <ProFormText
                                    name="author"
                                    label="毕业院校"
                                    placeholder="10"
                                />
                            </Col>
                            <Col span={8}>
                                <ProFormText
                                    name="author"
                                    label="专业"
                                    placeholder="10"
                                />
                            </Col>
                            <Col span={8}>
                                <ProFormCascader
                                    label="籍贯"
                                    name="native_arr"
                                    fieldProps={{
                                        fieldNames: cascaderfieldNames,
                                        options: dictModel.areaList,
                                        changeOnSelect: true
                                    }}
                                    placeholder="请选择籍贯"
                                />
                            </Col>
                            <Col span={8}>
                                <ProFormSelect
                                    name="marital_status"
                                    label="婚姻状况"
                                    fieldProps={{
                                        fieldNames: selectfieldNames
                                    }}
                                    options={dictModel.maritalList}
                                />
                            </Col>
                            <Col span={8}>
                                <ProFormText
                                    name="author"
                                    label="联系电话"
                                    placeholder="10"
                                />
                            </Col>
                            <Col span={8}>
                                <ProFormDatePicker
                                    name="dob"
                                    label="入户时间"
                                    placeholder='请选择入户时间'
                                    width={'lg'}
                                />
                            </Col>
                            <Col span={8}>
                                <ProFormText
                                    name="author"
                                    label="备注"
                                    placeholder="10"
                                />
                            </Col>
                        </Row>

                    </ProForm>
                </Modal>
            </ConfigProvider>
        </>
    );
};



export default connect(({ dictModel, openModel }: any) => ({
    dictModel, openModel
}))(PagesMainInformationArticleCreate);